==> GeneticsBase_1.0.0.tar.gz: GeneticsBase/R/HWE.geneSet.R <==
"HWE.geneSet" <- function( object,
                          #EST=c("D", "D'", "R"),
                          test=c("exact", "permutation", "chisq"),
                          B=10000,
                          R=1000,
                          correct=TRUE,
                          conf=c(0.95), #c(0.05, 0.95),
                          na.rm=TRUE,
                          ...
                         ) 
  {
    test <- match.arg(test, choices=c("exact", "permutation", "chisq"))
    nQuant <- length(conf)
    
    D <- matrix(nrow=nmarker(object), ncol=(3 + length(conf)))

    if(nQuant>0)
      colnames(D) <- c("Est", paste( conf*100, "%", sep=""),
                       "n", "P-value")
    else
      colnames(D) <- c("Est", "n", "P-value")
    
    rownames(D) <- markerNames(object)

    chisq <- Dprime <- r <- D
    
    for(marker in 1:nmarker(object) )
      {
        ld <- diseq.inner(object, marker)

        # Estimates
        D     [marker, "Est"] <- ld$D.overall
        Dprime[marker, "Est"] <- ld$Dprime.overall
        r     [marker, "Est"] <- ld$r.overall
        chisq [marker, "Est"] <- ld$chisq

        # Sample Sizes
        n <- sum(ld$observed.no)
        D     [marker, "n"] <- n
        Dprime[marker, "n"] <- n
        r     [marker, "n"] <- n
        chisq [marker, "n"] <- n


        ## do chisq test
        if(test=="exact")
          test.val  <- HWE.exact(object,marker)
        else
          {
            test.val  <- HWE.chisq(object, marker,
                                   simulate.p.value=(test=="permutation"),
                                   B=B,...)
          }

        # P-values
        D     [marker, "P-value"] <- test.val$p.value
        Dprime[marker, "P-value"] <- test.val$p.value
        r     [marker, "P-value"] <- test.val$p.value
        chisq [marker, "P-value"] <- test.val$p.value
        

        
        if(nQuant>0)
          {
            ci <- diseq.ci(
                           object=object,
                           marker=marker,
                           R=R,
                           conf=conf,
                           correct=correct,
                           na.rm=na.rm
                           )
            ind <- 1+(1:nQuant)
            D     [marker, ind ] <- ci$ci["Overall D " , ind]
            Dprime[marker, ind ] <- ci$ci["Overall D'", ind]
            r     [marker, ind ] <- ci$ci["Overall r " , ind]
          }
        
      }
    
    retval <- list("diseq",
                   call=match.call(),
                   "D"  =D,
                   "D'" =Dprime,
                   "r"  =r,
                   "X^2"=chisq
                   )
    retval
  }

setGeneric("HWE", function(object, ...)
           standardGeneric("HWE"))

setMethod("HWE", "geneSet",    HWE.geneSet)

==> GeneticsBase_1.14.0.tar.gz: GeneticsBase/R/HWE.geneSet.R <==
"HWE.geneSet" <- function( object,
                          test=c("exact", "permutation", "chisq"),
                          B=10000,
                          R=1000,
                          correct=TRUE,
                          conf=c(0.025, 0.975),
                          na.rm=TRUE,
                          founderOnly=FALSE,
                          ...
                         ) 
  {

    if(founderOnly==TRUE)
      {
        object<-founderGeneSet(object)
      }

    test <- match.arg(test, choices=c("exact", "permutation", "chisq"))
    nQuant <- length(conf)
    
    D <- matrix(NA, nrow=nmarker(object), ncol=(3 + length(conf)))

    if(nQuant>0)
      colnames(D) <- c("Est", paste( conf*100, "%", sep=""),
                       "n", "P-value")
    else
      colnames(D) <- c("Est", "n", "P-value")
    
    rownames(D) <- markerNames(object)

    chisq <- Dprime <- r <- D
    
    for(marker in 1:nmarker(object) )
      {
        ld <- diseq.inner(object, marker)

        # Estimates
        D     [marker, "Est"] <- ld$D.overall
        Dprime[marker, "Est"] <- ld$Dprime.overall
        r     [marker, "Est"] <- ld$r.overall
        chisq [marker, "Est"] <- ld$chisq

        # Sample Sizes
        n <- sum(ld$observed.no)
        D     [marker, "n"] <- n
        Dprime[marker, "n"] <- n
        r     [marker, "n"] <- n
        chisq [marker, "n"] <- n


        ## do chisq test
        if(test=="exact")
          test.val  <- HWE.exact(object,marker, founderOnly=founderOnly)
        else
          {
            test.val  <- HWE.chisq(object, marker,
                                   simulate.p.value=(test=="permutation"),
                                   B=B, founderOnly=founderOnly,...)
          }

        # P-values
        D     [marker, "P-value"] <- test.val$p.value
        Dprime[marker, "P-value"] <- test.val$p.value
        r     [marker, "P-value"] <- test.val$p.value
        chisq [marker, "P-value"] <- test.val$p.value
        

        
        if(nQuant>0)
          {
            ci <- diseq.ci(
                           object=object,
                           marker=marker,
                           R=R,
                           conf=conf,
                           correct=correct,
                           na.rm=na.rm
                           )
            ind <- 1+(1:nQuant)
            D     [marker, ind ] <- ci$ci["Overall D " , ind]
            Dprime[marker, ind ] <- ci$ci["Overall D'", ind]
            r     [marker, ind ] <- ci$ci["Overall r " , ind]
          }
        
      }
    
    retval <- list("diseq",
                   call=match.call(),
                   "D"  =D,
                   "D'" =Dprime,
                   "r"  =r,
                   "X^2"=chisq
                   )
    retval
  }

setGeneric("HWE", function(object,test=c("exact", "permutation", "chisq"),
           B=10000, R=1000, correct=TRUE, conf=c(0.95), na.rm=TRUE, founderOnly=TRUE, ...)
           standardGeneric("HWE"))

setMethod("HWE", "geneSet",    HWE.geneSet)
